from setuptools import setup

setup(name='ftThanos',
version="0.0.50",
description="A client for 50 API",
author="Thanos 50",
author_email="thanos@50paris.fr",
packages=["ftThanos"],
install_requires=["requests","python-dotenv"],
)
